@@ -503,8 +503,14 @@ class Bulb(object):
         if self._music_mode:
             return self._last_properties
 
-        capabilities = self.get_capabilities(2)
-        self._last_properties = {k:capabilities[k] for k in requested_properties if k in capabilities}
+        response = asyncio.run(self.get_a_prop("get_prop", requested_properties))
+        if (not response == None):
+            properties = response["result"]
+            properties = [x if x else None for x in properties]
+            self._last_properties = dict(zip(requested_properties, properties))
+        else:
+            capabilities = self.get_capabilities(2)
+            self._last_properties = {k:capabilities[k] for k in requested_properties if k in capabilities}
 
         if self._last_properties.get("power") == "off":
             cb = "0"
@@ -520,18 +526,39 @@ class Bulb(object):
         _LOGGER.debug(self._last_properties)
         return self._last_properties
 
-    async def updateProperties(self):
-        await asyncio.sleep(0.5)
-        self.get_properties()
 
-        # self._listenTask = asyncio.create_task(self.listener())
+    async def get_a_prop(self, method, params=None):
+        """
+        """
+
+        command = {"id": self._cmd_id, "method": method, "params": params}
+
+        try:
+            reader, writer = await asyncio.wait_for(asyncio.open_connection(
+                self._ip, self._port), timeout=2)
+            _LOGGER.debug("%s > %s", self, command)
+            await asyncio.sleep(0.1)
+            writer.write((json.dumps(command) + "\r\n").encode("utf8"))
+            await writer.drain()
+            data = await asyncio.wait_for(reader.readuntil(b'\r\n'), timeout=0.5)
+            _LOGGER.debug(data)
+            return json.loads(data.decode())
+        except asyncio.CancelledError:
+            return None
+        except asyncio.TimeoutError:
+            return None
+        except Exception as e:
+            _LOGGER.error(e)
+            raise BulbException(e)
+        finally:
+            writer.close()
+            await writer.wait_closed()
 
     async def send_command(self, method, params=None):
         """
         """
 
         command = {"id": self._cmd_id, "method": method, "params": params}
-        error = None
 
         try:
             reader, writer = await asyncio.wait_for(asyncio.open_connection(
@@ -540,12 +567,18 @@ class Bulb(object):
             await asyncio.sleep(0.1)
             writer.write((json.dumps(command) + "\r\n").encode("utf8"))
             await writer.drain()
+
+            data = await asyncio.wait_for(reader.readuntil(b'\r\n'), timeout=0.5)
+            _LOGGER.error(data)
+            json_data = json.loads(data.decode())
+            if ("params" in json_data):
+                self._last_properties.update(json_data["params"])
         except Exception as e:
+            _LOGGER.error(e)
             raise BulbException(e)
         finally:
             writer.close()
             await writer.wait_closed()
-            await asyncio.create_task(self.updateProperties())
 
     @_command
     def set_color_temp(self, degrees, light_type=LightType.Main, **kwargs):
